@@ -51,15 +51,19 @@ namespace Banshee.Plugins.Daap
         private ArrayList clients = new ArrayList();
         private ArrayList databases = new ArrayList();
       
-        public DaapProxyWebServer(ushort port) 
+        public DaapProxyWebServer() 
         {
-            this.port = port;
         }
 
         public void Start() 
         {
             server = new Socket(AddressFamily.InterNetwork, SocketType.Stream, ProtocolType.IP);
-            server.Bind(new IPEndPoint(IPAddress.Any, port));
+            try {
+                server.Bind(new IPEndPoint(IPAddress.Any, 8089));
+            } catch (System.Net.Sockets.SocketException) {
+                server.Bind(new IPEndPoint(IPAddress.Any, 0));
+            }
+            port = (ushort)(server.LocalEndPoint as IPEndPoint).Port;
             server.Listen(10);
 
             running = true;
@@ -282,6 +286,7 @@ namespace Banshee.Plugins.Daap
             Stream stream = database.StreamSong(song, out length);
             WriteResponseStream(client, stream, length, song.FileName);
             stream.Close();
+            client.Close();
         }
 
         private void WriteResponse(Socket client, HttpStatusCode code, string body) 
@@ -298,34 +303,49 @@ namespace Banshee.Plugins.Daap
             string headers = String.Empty;
             headers += String.Format("HTTP/1.1 {0} {1}\r\n", (int)code, code.ToString());
             headers += String.Format("Content-Length: {0}\r\n", body.Length);
-            headers += String.Format("Content-Type: text/html\r\n");
+            headers += "Content-Type: text/html\r\n";
+            headers += "Connection: close\r\n";
             headers += "\r\n";
             
             using(BinaryWriter writer = new BinaryWriter(new NetworkStream(client, false))) {
                 writer.Write(Encoding.UTF8.GetBytes(headers));
                 writer.Write(body);
             }
+            
+            client.Close();
         }
 
         private void WriteResponseStream(Socket client, Stream response, long length, string filename)
         {
             using(BinaryWriter writer = new BinaryWriter(new NetworkStream(client, false))) {
                 string headers = "HTTP/1.1 200 OK\r\n";
-                headers += String.Format("Content-Length: {0}\r\n", length);
+
+                if(length > 0) {
+                    headers += String.Format("Content-Length: {0}\r\n", length);
+                }
+                
                 if(filename != null) {
                     headers += String.Format("Content-Disposition: attachment; filename=\"{0}\"\r\n",
                         filename.Replace("\"", "\\\""));
                 }
+                
+                headers += "Connection: close\r\n";
                 headers += "\r\n";
                 
                 writer.Write(Encoding.UTF8.GetBytes(headers));
 
                 using(BinaryReader reader = new BinaryReader(response)) {
-                    long count = 0;
-                    while(count < length) {
-                        byte [] buffer = reader.ReadBytes(Math.Min(ChunkLength, (int)length - (int)count));
+                    while(true) {
+                        byte [] buffer = reader.ReadBytes(ChunkLength);
+                        if(buffer == null) {
+                            break;
+                        }
+                        
                         writer.Write(buffer);
-                        count += buffer.Length;
+                        
+                        if(buffer.Length < ChunkLength) {
+                            break;
+                        }
                     }
                 }
             }
@@ -344,22 +364,12 @@ namespace Banshee.Plugins.Daap
                 DateTime.Now.ToString());
         }
 
-        public ushort RequestedPort {
+        public ushort Port {
             get { 
                 return port;
             }
-            
-            set {
-                port = value; 
-            }
         }
 
-        public ushort BoundPort {
-            get { 
-                return (ushort)(server.LocalEndPoint as IPEndPoint).Port; 
-            }
-        }
-        
         private static IPAddress local_address = IPAddress.Parse("127.0.0.1");
         public IPAddress IPAddress {
             get {
@@ -369,7 +379,7 @@ namespace Banshee.Plugins.Daap
         
         public string HttpBaseAddress {
             get {
-                return String.Format("http://{0}:{1}/", IPAddress, BoundPort);
+                return String.Format("http://{0}:{1}/", IPAddress, Port);
             }
         }
     }
