@@ -56,6 +56,9 @@ namespace Banshee
 #endif
         }
         
+        [System.Runtime.InteropServices.DllImport("libdbus-glib-1")]
+        private static extern void dbus_g_thread_init();
+        
         private static void Startup(string [] args)
         {
             try {
@@ -63,6 +66,7 @@ namespace Banshee
             } catch {}
             
             Gtk.Application.Init();
+            dbus_g_thread_init();
         
             Globals.ArgumentQueue = new ArgumentQueue(new ArgumentLayout [] {
                 new ArgumentLayout("enqueue <files>","Files to enqueue, must be last argument specified"),
@@ -94,6 +98,7 @@ namespace Banshee
             HandleDbusCommands(dbus_core);
             
             Globals.Initialize();
+            StockIcons.Initialize();
             new Program(StringUtil.UcFirst(ConfigureDefines.PACKAGE), ConfigureDefines.VERSION, Modules.UI, args);
             PlayerCore.UserInterface = new Banshee.PlayerUI();
             
@@ -127,6 +132,11 @@ namespace Banshee
             }
             
             bool present = true;
+            
+            string [] files = Globals.ArgumentQueue.Files;
+            if(files.Length > 0) {
+                remote_player.EnqueueFiles(files);
+            }
         
             foreach(string arg in Globals.ArgumentQueue.Arguments) {
                 bool dequeue = true;
