@@ -247,7 +247,8 @@ namespace Banshee
         private void BuildWindow()
         {
             IconThemeUtils.SetWindowIcon(WindowPlayer);
-
+            WindowPlayer.Title = Branding.ApplicationLongName;
+            
             // Main Menu
             (gxml["MainMenuContainer"] as Container).Add(Globals.ActionManager.GetWidget("/MainMenu"));
       
@@ -306,7 +307,7 @@ namespace Banshee
             volumeButton.VolumeChanged += OnVolumeScaleChanged;
             
             // Footer 
-            LabelStatusBar = new Label(Catalog.GetString("Banshee Music Player"));
+            LabelStatusBar = new Label(Branding.ApplicationLongName);
             LabelStatusBar.Show();
             
             // Old Shuffle Button
@@ -404,6 +405,7 @@ namespace Banshee
             playlistView.DragDataGet += OnPlaylistViewDragDataGet;
             playlistView.DragDrop += OnPlaylistViewDragDrop;
             playlistView.Selection.Changed += OnPlaylistViewSelectionChanged;
+            playlistView.Vadjustment.Changed += OnPlaylistViewVadjustmentChanged;
                 
             playlistView.EnableModelDragSource(
                 Gdk.ModifierType.Button1Mask | Gdk.ModifierType.Button3Mask,
@@ -596,7 +598,6 @@ namespace Banshee
             PlaylistUtil.LoadSources();
 
             if(LocalQueueSource.Instance.Count > 0) {
-                SourceManager.AddSource(LocalQueueSource.Instance);
                 SourceManager.SetActiveSource(LocalQueueSource.Instance);
             } else if(Globals.ArgumentQueue.Contains("audio-cd")) {
                 SelectAudioCd(Globals.ArgumentQueue.Dequeue("audio-cd"));
@@ -648,7 +649,7 @@ namespace Banshee
             TrackInfo track = PlayerEngineCore.CurrentTrack;
             
             if(track == null) {
-                WindowPlayer.Title = Catalog.GetString("Banshee Music Player");
+                WindowPlayer.Title = Branding.ApplicationLongName;
                 trackInfoHeader.Visible = false;
                 return;
             }
@@ -922,6 +923,15 @@ namespace Banshee
                 !(source is AudioCdSource || source is DapSource);
         }
         
+        private void OnPlaylistViewVadjustmentChanged(object o, EventArgs args)
+        {
+            double max_offset = playlistView.Vadjustment.Upper - playlistView.Vadjustment.PageSize;
+            
+            if(playlistView.Vadjustment.Value > max_offset) {
+                playlistView.Vadjustment.Value = max_offset;
+            }
+        }
+        
         private void OnSourceManagerActiveSourceChanged(SourceEventArgs args)
         {
             ThreadAssist.ProxyToMain(HandleSourceChanged);
@@ -1178,7 +1188,7 @@ namespace Banshee
             
             ThreadAssist.ProxyToMain(delegate {
                 if(count == 0 && SourceManager.ActiveSource == null) {
-                    LabelStatusBar.Text = Catalog.GetString("Banshee Music Player");
+                    LabelStatusBar.Text = Branding.ApplicationLongName;
                 } else if(count == 0) {
                     LabelStatusBar.Text = String.Empty;
                 } else {
